==> qmpdclient-1.0.6.2.tar.gz: qmpdclient-1.0.6.2/src/playlistsview.cpp <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "mpd.h"
#include "mpdsong.h"
#include "mpdsongmodel.h"
#include "playlistsview.h"
#include <QDrag>
#include <QMenu>
#include <QMimeData>

PlaylistsView::PlaylistsView(QWidget *parent) : MPDSongView(parent, HeaderView::PLAYLISTSVIEW, false) {
	// menu
	m_enqueueAction = m_menu->addAction(QPixmap(":/icons/add.png"), tr("&Enqueue"), this, SLOT(enqueue()));
	m_playAction = m_menu->addAction(QPixmap(":/icons/play.png"), tr("&Play"), this, SLOT(play()));
	m_menu->addSeparator();
	m_removeAction = m_menu->addAction(QPixmap(":/icons/remove.png"), tr("&Delete"), this, SLOT(deletePlaylist()));
	m_removeAction->setShortcut(Qt::Key_Delete);
	m_removeAction->setShortcutContext(Qt::WidgetShortcut);
	addAction(m_removeAction);

	connect(m_mpd, SIGNAL(playlistsUpdated(MPDSongList)), this, SLOT(setSongs(MPDSongList)));
}

void PlaylistsView::selectionChanged(const QItemSelection &s, const QItemSelection &u) {
	MPDSongView::selectionChanged(s, u);
	bool t = selectedIndexes().size() > 0;
	m_removeAction->setEnabled(t);
	emit toggleActions(t);
	emit playlistChanged(m_mpd->songsInPlaylists(m_model->songs(selectedIndexes())));
}

void PlaylistsView::deletePlaylist() {
	m_mpd->deletePlaylists(m_model->songs(selectedIndexes()));
}

void PlaylistsView::startDrag(Qt::DropActions) {
	if (m_midButtonDrag)
		return;
	QDrag *drag = new QDrag(this);
	drag->setPixmap(QPixmap(":/icons/amarok/playlist.png"));
	QString songs = "";
	foreach (MPDSong *song, m_model->songs(selectedIndexes())) {
		songs += song->url() + "\n";
	}
	if (songs.isEmpty())
		return;
	QMimeData *mimeData = new QMimeData();
	mimeData->setData("qmpdclient/playlist", songs.toUtf8());
	drag->setMimeData(mimeData);
	drag->start();
}

==> qmpdclient-1.0.7.tar.gz: qmpdclient-1.0.7/src/playlistsview.cpp <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "metainfodialog.h"
#include "mpd.h"
#include "mpdsongmodel.h"
#include "playlistsview.h"
#include <QMenu>

PlaylistsView::PlaylistsView(QWidget *parent) : MPDSongView(parent, HeaderView::PLAYLISTSVIEW) {
	// Reconnect to avoid calling parent information slot
	disconnect(m_informationAction, SIGNAL(triggered()), this, SLOT(information()));
	connect(m_informationAction, SIGNAL(triggered()), this, SLOT(information()));
	m_menu->addSeparator();
	m_removeAction = m_menu->addAction(QPixmap(":/icons/remove.png"), tr("&Delete"), this, SLOT(deletePlaylist()));
	m_removeAction->setShortcut(Qt::Key_Delete);
	m_removeAction->setShortcutContext(Qt::WidgetShortcut);
	addAction(m_removeAction);

	connect(m_mpd, SIGNAL(playlistsUpdated(MPDSongList)), this, SLOT(setSongs(MPDSongList)));
}

void PlaylistsView::selectionChanged(const QItemSelection &s, const QItemSelection &u) {
	MPDSongView::selectionChanged(s, u);
	bool t = selectedIndexes().size() > 0;
	m_removeAction->setEnabled(t);
	emit toggleActions(t);
	emit playlistChanged(m_mpd->songsInPlaylists(m_model->songs(selectedIndexes())));
}

void PlaylistsView::deletePlaylist() {
	m_mpd->deletePlaylists(m_model->songs(selectedIndexes()));
}

void PlaylistsView::information() {
	new MetaInfoDialog(this, m_mpd->songsInPlaylists(m_model->songs(selectedIndexes())));
}
